@@ -210,12 +210,14 @@ class IBBrokerAPI(BrokerAPIBase):
     def connect(self,
                 address: str = '127.0.0.1',
                 port: int = 4002,
-                client_id: int = 1,
-                is_async: bool = True) -> None:
-        if is_async:
-            self.get_handle().connectAsync(address, port, clientId=client_id)
-        else:
-            self.get_handle().connect(address, port, clientId=client_id)
+                client_id: int = 1) -> None:
+        self.get_handle().connect(address, port, clientId=client_id)
+
+    async def async_connect(self,
+                address: str = '127.0.0.1',
+                port: int = 4002,
+                client_id: int = 1) -> None:
+        await self.get_handle().connectAsync(address, port, clientId=client_id)
 
     def disconnect(self):
         self.get_handle().disconnect()
@@ -566,8 +568,11 @@ class IBPortfolioManager(PortfolioManagerBase):
                 position_closed = min(abs(existing_position), abs(combo_unit))
             existing_pnl = (self.portfolio_info_df.loc[(self.portfolio_info_df['strategy_name'] == strategy_name) &
                                                        (self.portfolio_info_df['combo_name'] == combo_name),
-                                                       'realized_pnl'])
-            existing_holding_direction = existing_position / abs(existing_position)
+                                                       'realized_pnl']).iloc[0]
+
+            existing_holding_direction = (existing_position / abs(existing_position)
+                                          if abs(existing_position) > utils.EPSILON else 0.0)
+
             (self.portfolio_info_df.loc[(self.portfolio_info_df['strategy_name'] == strategy_name) &
                                         (self.portfolio_info_df['combo_name'] == combo_name),
                                         'realized_pnl']) = existing_pnl + existing_holding_direction * position_closed\
@@ -799,7 +804,7 @@ class IBOrderManager(OrderManagerBase):
         buy_sell: str = 'BUY' if order_amount > utils.EPSILON else 'SELL'
         if order_type == 'MKT':
             ib_order = ibi.order.MarketOrder(buy_sell, abs(order_amount))
-            trade_object = self._broker_handle.placeOrder(contract.get_contract(), ib_order)
+            trade_object = self._broker_handle.placeOrder(contract, ib_order)
             return trade_object
         else:
             # TBD: Support other order types
@@ -874,7 +879,9 @@ class IBOrderManager(OrderManagerBase):
                 return
 
             # Update dangling order status.
-            self.order_info_df.loc[self.order_info_df['order_id'] == order_id, 'dangling_order'] -= filled_amount
+            order_direction = 1.0 if trade.order.action == 'BUY' else -1.0
+            self.order_info_df.loc[self.order_info_df['order_id'] == order_id, 'dangling_order']\
+                -= order_direction * filled_amount
 
             # Record leg entry price
             self.order_info_df.loc[self.order_info_df['order_id'] == order_id, 'entry_price'] = average_fill_price
